\name{dat.bakdash2021}
\docType{data}
\alias{dat.bakdash2021}
\title{Dataset on situation awareness and task performance associations}
\description{Results from 77 papers with 678 effects evaluating 
associations among measures of situation awareness and task performance.}
\usage{
dat.bakdash2021
}
\format{
The data frame contains the following columns:
\tabular{lll}{
\bold{Author}            \tab \code{character} \tab Paper author(s) \cr
\bold{Year}              \tab \code{integer}   \tab Year of paper publication \cr
\bold{Title}             \tab \code{character} \tab Title of paper \cr
\bold{DOI}               \tab \code{character} \tab Digitial Object Identifier (DOI) \cr
\bold{DTIC.link}         \tab \code{character} \tab Permament link for Defense Technical Information Collection (DITC)                                                   reports, see: \verb{https://www.dtic.mil} \cr
\bold{SA.measure.type}   \tab \code{character} \tab Type of SA measure \cr
\bold{Sample.size}       \tab \code{integer}   \tab Reported sample size \cr
\bold{Sample.size.stats} \tab \code{integer}   \tab Reported sample size based on reported statistics. This reflects excluded participants. \cr
\bold{es.z}              \tab \code{numeric}   \tab Z-transformed correlation coefficient. Includes ghost results (disclosed and undisclosed non-significant effects not reported in detail) imputed using the draw method described in Bakdash et al. (2021a) \cr
\bold{vi.z}               \tab \code{numeric}   \tab Variance for Z-transformed correlation (calculated using Sample.size.stats, \emph{not} Sample.size) \cr
\bold{SampleID}           \tab \code{numeric}   \tab Unique identifier for each experiment/study \cr
\bold{Outcome}            \tab \code{integer}   \tab Unique value for each effect size \cr
\bold{Comments}           \tab \code{character} \tab Comments about the data extraction and coding \cr
}  
}
\details{
   The dataset contains behavioral experiments from 77 papers/79 studies with a total of 678 effects, evaluating associations among measures of situation awareness ("knowing what is going on") and task performance. Examples of situation awareness include knowledge of current vehicle speed in a simulated driving task and location and heading of aircraft in a simulated air traffic control task. Corresponding examples of task performance include "the number of collisions in a simulated driving task" and "subject matter expert rating of conflict management in a simulated air control task" (Bakdash et al. 2021a, p. 2). This dataset and the 'Examples' are a highly simplified version of the data and code in Bakdash et al. (2021b; 2021c). The journal article by Bakdash et al. 2021a. describes the systematic review and meta-analysis in detail. 
  
This dataset is used to illustrate multilevel multivariate meta-analytic models for the overall pooled effect and pooled effects by situation awareness measure. We also adjust meta-analytic models using Cluster Robust Variance Estimation/Cluster Robust Inference with the \code{robust} function in \emph{metafor}: \url{https://www.metafor-project.org/}. Results are shown graphically in a customized forest plot with a prediction interval (estimated plausible range of individual effects). Last, we create a table summarizing estimated meta-analytic heterogeneity parameters. 

The meta-analytic results show most pooled effect sizes in the positive medium range or less. There was also substantial meta-analytic heterogeneity (estimated systematic variance in true effects), nearing the magnitude of the overall pooled effect. We interpret the meta-analytic results as situation awareness typically having limited validity for task performance (i.e., good situation awareness does not tend to have strong probabilistic links with good performance and vice-versa). More formally, measures of situation awareness do not generally and meaningfully capture cognitive processes and other relevant factors underlying task performance.      

\subsection{Run-Time}
The code run-time can be greatly speed-up using multiple CPU cores and a linear algebra library with \emph{R}. See: \url{https://www.metafor-project.org/doku.php/tips:speeding_up_model_fitting}. To measure the run-time, uncomment these three lines: \code{start.time <-Sys.time()}, \code{end.time <-Sys.time()}, and \code{end.time - start.time}.

Run-times on Windows 10 x64 with the Intel Math Kernel Library installed for \emph{R}: 
\tabular{rll}{
\tab \emph{CPU} \tab \emph{Run-Time (Minutes)} \cr
\tab i7-11850H  \tab 2.49 \cr
\tab i7-4770    \tab 5.38 \cr
}

}

\source{
  Bakdash, J. Z., Marusich, L. R., Cox, K. R., Geuss, M. N., Zaroukian, E. G., & Morris, K. M. (2021b). The validity of situation awareness for performance: A meta-analysis (Code Ocean Capsule). \verb{https://doi.org/10.24433/CO.1682542.v4}

  Bakdash, J. Z., Marusich, L. R., Cox, K. R., Geuss, M. N., Zaroukian, E. G., & Morris, K. M. (2021c). The validity of situation awareness for performance: A meta-analysis (Systematic Review, Data, and Code). \verb{https://doi.org/10.17605/OSF.IO/4K7ZV}
}  
\references{
   Bakdash, J. Z., Marusich, L. R., Cox, K. R., Geuss, M. N., Zaroukian, E. G., & Morris, K. M. (2021a). The validity of situation awareness for performance: A meta-analysis. \emph{Theoretical Issues in Ergonomics Science}, 1--24. \verb{https://doi.org/10.1080/1463922X.2021.1921310}.
   
- Supplemental material: \verb{https://www.tandfonline.com/doi/suppl/10.1080/1463922X.2021.1921310/suppl_file/ttie_a_1921310_sm5524.docx} 
}
\author{
   Jonathan Bakdash, \email{jonathan.z.bakdash.civ@army.mil}, \email{jbakdash@gmail.com},
   
   Laura Marusich, \email{laura.m.cooper20.civ@army.mil}, \email{lmarusich@gmail.com} 
}

\examples{
### copy data into 'dat' and examine data
dat <- dat.bakdash2021
head(dat)

\dontrun{
#start.time <-Sys.time()
### load metafor and other required packages (knitr and psych)
require(metafor)
require(knitr)
require(psych)

### Only the overall pooled effect 
res.overall <- rma.mv(es.z,  vi.z, mods = ~ 1, 
                      random = ~ 1|SampleID/Outcome,
                      data = dat, 
                      test="t")

#### res.overall in Z
predict(res.overall, digits = 4)

#### Cluster Robust Variance Estimation (CRVE) or Cluster-Robust Inference  
### Note CRVE results are the same 
#### as the unadjusted results from res.overall, to four decimal places. 
res.overall.crve <- rma.mv(es.z,  vi.z, mods = ~ 1, 
                          random = ~ 1|SampleID/Outcome,
                          data = dat, 
                          test="t")

#### Results in Z 
res.overall.crve.pred <- predict(res.overall.crve)

### Multilevel meta-analytic model for SA measures
#### Effects nested in "papers" or unique experiments/studies  
res.sa <-  rma.mv(es.z,  vi.z, mods = ~ SA.measure.type - 1, 
                          random = ~ 1|SampleID/Outcome,
                          data = dat, 
                          test="t")
res.sa

#### CRVE: Note slight differences for CRVE vs. unadjusted model
res.sa.crve <- robust(res.sa, cluster = dat$SampleID)
res.sa.crve

#### Profile plot
par(mfrow=c(2,1))
profile(res.sa.crve, progbar = FALSE)


#### Format and combine output of meta-analytic models for the forest plot
all.z         <- c(res.sa.crve$beta,       #SA measures
                   res.overall.crve$beta,  #Pooled effect for CI
                   res.overall.crve$beta)  #Pooled effect for Pred Interval (PI)

all.ci.lower  <- c(res.sa.crve$ci.lb,            #SA measures
                   res.overall.crve.pred$ci.lb,  #Pooled effect, Lower CI
                   res.overall.crve.pred$pi.lb)  #Pooled effect, Lower PI

all.ci.upper <- c(res.sa.crve$ci.ub,            #SA measures
                  res.overall.crve.pred$ci.ub,  #Pooled effect, Upper CI
                  res.overall.crve.pred$pi.ub)  #Pooled effect, Lower PI

#### Note, there is no p-value for the PI
all.pvals       <- c(res.sa.crve$pval, res.overall.crve$pval)

all.labels <- c(sort(unique(dat$SA.measure.type)), "Overall", 
                "95\% Prediction Interval")

#### Function to round p-values for the forest plot
pvals.round<- function(input)
{
  input <- ifelse(input < 0.001, "< 0.001",
                  ifelse(input < 0.01, "< 0.01",
                         ifelse(input < 0.05 & input >= 0.045, "< 0.05",
                                ifelse(round(input, 2) == 1.00, "0.99",
                                       sprintf("\%.2f", round(input, 2)))
                         )  
                  )                   
  )
}

all.pvals.rounded <- pvals.round(all.pvals)

### Forest plot 
plot.vals <- data.frame(all.labels, all.z, all.ci.lower, all.ci.upper)
#measure.labels.all

par(mfrow=c(1,1), cex = 1.05)
forest(plot.vals$all.z, 
       ci.lb = plot.vals$all.ci.lower, 
       ci.ub = plot.vals$all.ci.upper, 
       slab  = plot.vals$all.labels, 
       psize = 1,
       efac = 0, xlim = c(-1.8, 2.5), clim = c(-1, 1), 
       transf = transf.ztor, #Transform z to r
       at = seq(-0.5 , 1, by = 0.25), 
       xlab = expression("Correlation Coefficient"~"("*italic('r')*")"), 
       main = "\n\n\nSA Measures",
       #main = "\n\n\nMeta-Analytic Model of SA Measures:\n All Reported Effects",
       ilab = c(all.pvals.rounded, ""), ilab.xpos = 2.45, ilab.pos = 2.5,
       digits = 2,                              
       refline = 0,
       annotate = F
       )

##### Keep trailing zero using sprintf
output <- cbind(sprintf("\%.2f", round(fisherz2r(plot.vals$all.z), 2)),        
                sprintf("\%.2f", round(fisherz2r(plot.vals$all.ci.lower), 2)), 
                sprintf("\%.2f", round(fisherz2r(plot.vals$all.ci.upper), 2))
                )

##### Alignment kludge
annotext <-  apply(output, 1, function(x) {paste0("  ",x[1], " [", x[2],", ", x[3], "]")})
text(1.05, c(12:1), annotext, pos = 4, cex = 1.05)

text(-1.475, 14.00, "SA Measure", cex = 1.05)
text(2.30,   14.00, substitute(paste(italic('p-value'))), cex = 1.05)
text(1.55,   14.00, "Correlation [95\% CI]", cex = 1.05)
abline(h = 1.5)

##### Black polygon for overall mean CIs
addpoly(all.z[11], ci.lb = all.ci.lower[11], ci.ub = all.ci.upper[11], 
        rows = 2, annotate=FALSE, efac = 1.5, transf = transf.ztor)

##### White polygon for PI
addpoly(all.z[12], ci.lb = all.ci.lower[12], ci.ub = all.ci.upper[12],  
        rows = 1, col = "white", border = "black", 
        annotate=FALSE, efac = 1.5, transf = transf.ztor)

#dev.copy(pdf, file="SA_measures_forest.pdf", 8, 6)
#dev.off()
par(mfrow=c(1,1), cex = 1) #Reset graph parameters to default

#### Meta-analytic heterogeneity
re.CI.variances <- confint(res.overall)
re.CI.variances 

sigma1.z <- data.frame(re.CI.variances[[1]]["random"])
sigma2.z <- data.frame(re.CI.variances[[2]]["random"])

##### Heterogeneity: http://www.metafor-project.org/doku.php/tips:i2_multilevel_multivariate 
W <- diag(1/dat$vi.z)
X <- model.matrix(res.overall)
P <- W - W \%*\% X \%*\% solve(t(X) \%*\% W \%*\% X) \%*\% t(X) \%*\% W

#### I2: Variance due to heterogeneity: 61\%
I2 <- 100 * sum(res.overall$sigma2) / 
              (sum(res.overall$sigma2) + 
              (res.overall$k-res.overall$p)/sum(diag(P)))
I2

##### 95\% CI for I2 using uncertainty around sigma
sigma.lower <- sum(sigma1.z$random.ci.lb[1]) + sigma2.z$random.ci.lb[1]
sigma.upper <- sum(sigma1.z$random.ci.ub[1]) + sigma2.z$random.ci.ub[1]

##### 95\% CI lower
I2.CI.lb <- 100 *  sigma.lower / 
                    (sigma.lower + (res.overall$k-res.overall$p)/sum(diag(P)))
I2.CI.lb

###### 95\% CI upper
I2.CI.ub <- 100 *  sigma.upper / 
                    (sigma.upper + (res.overall$k-res.overall$p)/sum(diag(P)))
I2.CI.ub

###### Total heterogeneity (tau)  
# Note simply adding tau1 (0.17) and tau2 (0.12) together produces an inflated tau
# sigma1[2,1] + sigma2[2,1]
# Another way to calc this correctly: sqrt(sigma1[2,1]^2 + sigma2[2,1]^2)

res.overall.alt <- rma.mv(es.z,  vi.z, mods = ~ 1, 
                          random = ~ factor(Outcome)|factor(SampleID), 
                          data = dat, 
                          test="t")

res.overall.alt.tau <- confint(res.overall.alt)[[1]]$random

total.tau.z         <- res.overall.alt.tau[2,1]
total.tau.z.lowerCI <- res.overall.alt.tau[2,2]
total.tau.z.upperCI <- res.overall.alt.tau[2,3]

total.tau.vals.z <- c(total.tau.z, total.tau.z.lowerCI, total.tau.z.upperCI)

table.heterogeneity <- data.frame(matrix(ncol = 3, nrow = 4)) 
colnames(table.heterogeneity) <- c("Parameter Value", 
                                   "Lower 95\% CI", 
                                   "Upper 95\% CI")
rownames(table.heterogeneity) <- c("Tau (Total)",  
                                   "Tau1 (Between paper)", 
                                   "Tau2 (Within paper)", 
                                   "I2 (\%)")

table.heterogeneity[1,] <- fisherz2r(total.tau.vals.z)
table.heterogeneity[2,] <- c(fisherz2r(sigma1.z[2,]))
table.heterogeneity[3,] <- c(fisherz2r(sigma2.z[2,]))
table.heterogeneity[4,] <- c(I2, I2.CI.lb, I2.CI.ub)


kable(as.matrix(round(table.heterogeneity, 2)), format = "markdown",  
      row.names = TRUE, 
      caption = "Meta-Analytic Heterogeneity")
#write.csv(as.matrix(round(table.heterogeneity, 2)), file = "table.heterogeneity.csv")
  }
#end.time <-Sys.time()
#end.time - start.time
}
\keyword{datasets}
\concept{psychology}
\concept{human factors}
\concept{engineering}
\concept{correlation coefficients}
\concept{multilevel models}
\concept{multivariate models}
\concept{cluster-robust inference}
\concept{heterogeneity}

